@@ -3,7 +3,7 @@ from netmiko import ConnectHandler
 from collections import namedtuple
 
 
-class cisco(object):
+class cisco_ios(object):
     def __init__(self,ac_info,dev_info):
         self.username = ac_info.username
         self.password = ac_info.password
