@@ -3,7 +3,7 @@
 from netmiko import ConnectHandler
 from collections import namedtuple
 
-class base_junos(object):
+class juniper_junos(object):
     def __init__(self, ac_info, dev_info):
         self.username = ac_info.username
         self.password = ac_info.password
@@ -21,6 +21,8 @@ class base_junos(object):
             'timeout': 3600,
             'verbose': True,
         }
+
+
     def account_verification(self, config_mode_tag="#"):
         """
         验证账号是否有配置权限，返回提示符
@@ -89,6 +91,10 @@ class base_junos(object):
         for line in check_list:
             show_configs = net_connect.send_command("show security flow session source-prefix " + line)
             check_result = check_result + show_configs + "\n"
+
+        for line in check_list:
+            show_configs = net_connect.send_command("show security flow session destination-prefix " + line)
+            check_result = check_result + show_configs + "\n"
         net_connect.disconnect()
         return check_result
 
@@ -111,7 +117,6 @@ class base_junos(object):
         return True
 
 
-class srx_550(base_junos):
     def generate_routing_script(self, route_info_list):
         """
         生成路由的脚本，传入的参数是一个ip列表，如： [ "1.1.1.1","2.2.2.2" ]
@@ -125,10 +130,4 @@ class srx_550(base_junos):
         return routing_script_list
 
     # def gen_routing_policy(self):
-    pass
-
-
-class srx_350(base_junos):
-    # def gen_routing_policy(self):
-    pass
-
+    pass
\ No newline at end of file
